@@ -387,9 +387,10 @@ class AnnotatedWord(Word):
 
     def getUniversalDependencyFormat(self, sentenceLength: int) -> str:
         if self.__parse is not None:
+            uPos = self.__parse.getUniversalDependencyPos()
             result = self.name + "\t" + self.__parse.getWord().getName() + "\t" + \
-                     self.__parse.getUniversalDependencyPos() + "\t_\t"
-            features = self.__parse.getUniversalDependencyFeatures()
+                     uPos + "\t_\t"
+            features = self.__parse.getUniversalDependencyFeatures(uPos)
             if len(features) == 0:
                 result = result + "_"
             else:
